pub struct Decoder<R: Read> { /* fields omitted */ }Expand description
Creates a new decoder builder
Reads the logical screen descriptor including the global color palette
Returns a Reader. All decoder configuration has to be done beforehand.
Result type of set_param.
Sets self as a parameter of Object.
Result type of set_param.
Sets self as a parameter of Object.
Result type of set_param.
Sets self as a parameter of Object.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.